Learn R Programming

ROpenDota (version 0.1.2)

get_match_details: Get Match Details

Description

Get details of a single match

Usage

get_match_details(match_id)

Arguments

match_id

Dota2 match id. You can get them of a specific player using get_matches.

Value

GetMatchDetails returns a list, which includes the details like result, duration and etc.

Examples

Run this code
# NOT RUN {
match_id = "3114150257"
matchDetails <- get_match_details(match_id)
# }

Run the code above in your browser using DataLab