powered by
Get details of a single match
get_match_details(match_id)
Dota2 match id. You can get them of a specific player using get_matches.
get_matches
GetMatchDetails returns a list, which includes the details like result, duration and etc.
# NOT RUN { match_id = "3114150257" matchDetails <- get_match_details(match_id) # }
Run the code above in your browser using DataLab